/* -*- linux-c -*- */

/* gtkcombobox.h - GtkComboBox widget header
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GTK_COMBO_BOX_H__
#define __GTK_COMBO_BOX_H__

#include <gtk/gtkcontainer.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_COMBO_BOX            (gtk_combo_box_get_type ( ))
#define GTK_COMBO_BOX(object)         (GTK_CHECK_CAST ((object), GTK_TYPE_COMBO_BOX, GtkComboBox))
#define GTK_COMBO_BOX_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_COMBO_BOX))
#define GTK_IS_COMBO_BOX(object)      (GTK_CHECK_TYPE ((object), GTK_TYPE_COMBO_BOX))
#define GTK_IS_COMBO_BOX_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_COMBO_BOX))

typedef struct  _GtkComboBoxClass   GtkComboBoxClass;
typedef struct  _GtkComboBox        GtkComboBox;

struct _GtkComboBox
{
	GtkContainer  container;
	
	GtkWidget    *pop_down_widget;
	GtkWidget    *display_widget;
	
	GtkWidget    *frame;
	GtkWidget    *arrow_button;
	GtkWidget    *toplevel;
	GtkWidget    *tearoff_window;
	gboolean      torn_off;
	guint         use_arrows:1;
	
	GtkWidget    *tearable;
	GtkWidget    *popup;
};

struct _GtkComboBoxClass
{
	GtkContainerClass     parent_class;

	void   (*activate)   ( GtkComboBox    *cbox );
	void   (*popup)      ( GtkComboBox    *cbox );
	void   (*popdown)    ( GtkComboBox    *cbox );
};

GtkType      gtk_combo_box_get_type             ( void );
void         gtk_combo_box_construct            ( GtkComboBox *cbox,
						  GtkWidget *display_widget,
						  GtkWidget *pop_down_widget );
GtkWidget   *gtk_combo_box_new                  ( GtkWidget *display_widget,
						  GtkWidget *pop_down_widget );
void         gtk_combo_box_popup_hide           ( GtkComboBox *cbox );
void         gtk_combo_box_set_arrow_relief     ( GtkComboBox *cbox,
						  GtkReliefStyle relief );
void         gtk_combo_box_set_display          ( GtkComboBox *cbox,
						  GtkWidget *display_widget );
void         gtk_combo_box_set_sensitive        ( GtkComboBox *cbox,
						  gboolean sensitive );
void         gtk_combo_box_set_title            ( GtkComboBox *cbox,
					          const gchar *title );

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GTK_COMBO_BOX_H__ */
